# PyGFAutoDoc
## v0.1.2

Автоматический генератор документации
в формате GitFlic-книги для проектов на Python.

---

## Установка

> **Внимание!** Версия Python должна быть 3.10 или выше.

Введите в терминале:

```sh
pip install py_gf_auto_doc
```

---

## Использование

Формат использования:

```sh
python -m py_gf_auto_doc [-h]
                         --dir | -d <каталог Python-проекта>
                         --out_dir | -o <каталог для сохранения документации>
```

> **Внимание!** Если каталог `out_dir` не существует,
> возбуждается исключение `FileNotFoundError`.
